<?php
session_start();

// Caminho do arquivo de configuração
$config_file = 'admin/config.txt'; // Verifique o caminho correto do arquivo config.txt

// Verifica se o arquivo de configuração existe
if (file_exists($config_file)) {
    $config = file($config_file, FILE_IGNORE_NEW_LINES);
    $white_page = $config[0];  // Slug ou URL da página white
    $black_page = $config[1];  // Slug ou URL da página black
    $white_option = isset($config[2]) ? $config[2] : '';  // Opção da página white (normal, redirecionamento ou erro 404)
    $black_option = isset($config[3]) ? $config[3] : '';  // Opção da página black (normal ou redirecionamento)
} else {
    die("Configurações não encontradas. Configure as páginas primeiro.");
}

// Função para verificar se o visitante está vindo do TikTok pelo User-Agent
function isFromTikTok() {
    $userAgent = $_SERVER['HTTP_USER_AGENT'];

    // Verifica se o User-Agent contém os padrões do TikTok
    return (strpos($userAgent, 'musical_ly') !== false || strpos($userAgent, 'BytedanceWebview') !== false);
}

// Função para verificar se o dispositivo é mobile
function isMobile() {
    // Verifica diversos padrões comuns de user agents móveis
    return preg_match('/Mobile|Android|iPhone|iPad|iPod|BlackBerry|Opera Mini|IEMobile|WPDesktop/', $_SERVER['HTTP_USER_AGENT']);
}

// Página de erro 404 personalizada
function show404() {
    http_response_code(404);
    echo '
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Página Não Encontrada - Erro 404</title>
        <style>
            body {
                background-color: #000;
                color: #fff;
                font-family: Arial, sans-serif;
                text-align: center;
                display: flex;
                justify-content: center;
                align-items: center;
                height: 100vh;
                margin: 0;
                flex-direction: column;
            }
            h1 {
                font-size: 5rem;
                margin: 0;
                color: #f39c12;
            }
            p {
                font-size: 1.5rem;
                margin: 20px 0;
                color: #aaa;
            }
            a {
                color: #f39c12;
                text-decoration: none;
            }
            footer {
                position: absolute;
                bottom: 20px;
                font-size: 12px;
                color: #888;
            }
        </style>
        <!-- Google Analytics -->
        <script async src="https://www.googletagmanager.com/gtag/js?id=G-HHVFX3HTTL"></script>
        <script>
          window.dataLayer = window.dataLayer || [];
          function gtag(){dataLayer.push(arguments);}
          gtag("js", new Date());
          gtag("config", "G-HHVFX3HTTL");
        </script>
    </head>
    <body>
        <h1>404</h1>
        <p>Página Não Encontrada</p>
        <p>A página que você está tentando acessar não existe ou foi movida.</p>
        <footer>Cloaker desenvolvido por <a href="https://www.instagram.com/brenohonori0" target="_blank">Breno Honorio</a></footer>
    </body>
    </html>';
    exit;
}


// Função para redirecionar para uma URL externa
function redirectToUrl($url) {
    header("Location: $url");
    exit();
}

// Decide qual opção usar para a página white
if (!isFromTikTok() || !isMobile()) {
    // 1. Verifica se deve redirecionar a página white para uma URL externa
    if ($white_option === 'redirect') {
        redirectToUrl($white_page);  // Redireciona para a URL externa configurada
    }

    // 2. Verifica se deve mostrar erro 404
    elseif ($white_option === '404') {
        show404();  // Exibe a página 404
    }

    // Se nenhuma das opções for configurada, usa a slug normalmente
    else {
        $slug = $white_page;
    }
} else {
    // Decide qual opção usar para a página black
    if ($black_option === 'redirect') {
        redirectToUrl($black_page);  // Redireciona para a URL externa configurada para black
    } else {
        $slug = $black_page;
    }
}

// Caminho para o index.html ou index.php dentro da pasta
$target_path_html = $_SERVER['DOCUMENT_ROOT'] . "/$slug/index.html";
$target_path_php = $_SERVER['DOCUMENT_ROOT'] . "/$slug/index.php";

// Verifica se existe um arquivo index.html ou index.php na pasta do slug
if (file_exists($target_path_html)) {
    $page_content = file_get_contents($target_path_html);  // Pega o conteúdo do index.html
} elseif (file_exists($target_path_php)) {
    ob_start();
    include($target_path_php);   // Executa o index.php e captura o output
    $page_content = ob_get_clean();
} else {
    die("O arquivo index não foi encontrado na pasta: /$slug");
}

// Injeta a tag <base> para ajustar os caminhos relativos
$base_url = "https://chazinsecreto.com/$slug/";
$page_content = str_replace('<head>', '<head><base href="' . $base_url . '">', $page_content);

// Exibe o conteúdo da página com a tag <base> injetada
echo $page_content;
