<?php
session_start();

// Verifica se o usuário está logado
if (!isset($_SESSION['loggedin'])) {
    header("Location: login.php");
    exit;
}

// Caminho do arquivo de configuração
$config_file = 'config.txt';

// Se o formulário foi enviado, atualiza as configurações
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $white_page = $_POST['white_page'];
    $black_page = $_POST['black_page'];
    $white_option = $_POST['white_option']; // Salvando a opção selecionada do checkbox

    // Escreve as configurações no arquivo
    file_put_contents($config_file, "$white_page\n$black_page\n$white_option");
    $message = "Configurações atualizadas com sucesso!";
}

// Lê as configurações atuais
if (file_exists($config_file)) {
    $config = file($config_file, FILE_IGNORE_NEW_LINES);
    $current_white = $config[0];
    $current_black = $config[1];
    $white_option = isset($config[2]) ? $config[2] : '';
} else {
    $current_white = '';
    $current_black = '';
    $white_option = '';
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configurações - Cloaker</title>
    <style>
        body {
            background-color: #000;
            color: #fff;
            font-family: Arial, sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }
        .config-container {
            background-color: #1a1a1a;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.5);
            width: 400px;
            text-align: center;
        }
        h1 {
            margin-bottom: 20px;
            color: #f5f5f5;
        }
        input[type="text"] {
            width: 100%;
            padding: 10px;
            margin: 10px 0;
            border: none;
            border-radius: 5px;
            background-color: #333;
            color: #fff;
            box-sizing: border-box;
        }
        input[type="text"]:disabled {
            background-color: #555;
            color: #999;
        }
        button {
            width: 100%;
            padding: 10px;
            background-color: #f39c12;
            border: none;
            border-radius: 5px;
            color: #fff;
            cursor: pointer;
            transition: background-color 0.3s;
        }
        button:hover {
            background-color: #e67e22;
        }
        .message {
            color: #2ecc71;
            margin-bottom: 20px;
        }
        .checkbox-group {
            text-align: left;
            margin-bottom: 15px;
        }
        .checkbox-group label {
            color: #f5f5f5;
        }
    </style>
    <script>
        // Função para controlar o comportamento dos checkboxes e inputs
        function handleCheckboxChange() {
            var redirectCheckbox = document.getElementById('redirect');
            var error404Checkbox = document.getElementById('error404');
            var slugRaizCheckbox = document.getElementById('slug_raiz');
            var whiteInput = document.getElementById('white_page');
            var whiteLabel = document.getElementById('white_label');

            // Verifica o estado inicial ao carregar a página
            if (error404Checkbox.checked) {
                whiteInput.disabled = true;
                whiteInput.value = "A página white está sendo redirecionada para erro 404";
                whiteLabel.textContent = "Página white está sendo redirecionada para erro 404:";
            } else if (redirectCheckbox.checked) {
                whiteInput.disabled = false;
                whiteInput.placeholder = "Adicione a URL para redirecionamento";
                whiteLabel.textContent = "Adicione a URL para redirecionamento da página white:";
            } else if (slugRaizCheckbox.checked) {
                whiteInput.disabled = false;
                whiteInput.placeholder = "Adicione a slug da página white na raiz";
                whiteLabel.textContent = "Adicione a slug para a página white na raiz:";
            }

            // Desmarca os outros checkboxes quando um é selecionado
            redirectCheckbox.addEventListener('change', function() {
                if (this.checked) {
                    error404Checkbox.checked = false;
                    slugRaizCheckbox.checked = false;
                    whiteInput.disabled = false;
                    whiteInput.placeholder = "Adicione a URL para redirecionamento";
                    whiteInput.value = '';
                    whiteLabel.textContent = "Adicione a URL para redirecionamento da página white:";
                }
            });

            error404Checkbox.addEventListener('change', function() {
                if (this.checked) {
                    redirectCheckbox.checked = false;
                    slugRaizCheckbox.checked = false;
                    whiteInput.disabled = true;
                    whiteInput.value = "A página white está sendo redirecionada para erro 404";
                    whiteLabel.textContent = "Página white está sendo redirecionada para erro 404:";
                }
            });

            slugRaizCheckbox.addEventListener('change', function() {
                if (this.checked) {
                    redirectCheckbox.checked = false;
                    error404Checkbox.checked = false;
                    whiteInput.disabled = false;
                    whiteInput.placeholder = "Adicione a slug da página white na raiz";
                    whiteInput.value = '';
                    whiteLabel.textContent = "Adicione a slug para a página white na raiz:";
                }
            });
        }

        // Chama a função ao carregar a página
        window.onload = function() {
            handleCheckboxChange();
        }
    </script>
</head>
<body>
    <div class="config-container">
        <h1>Configurações de Cloaking</h1>
        <?php if (isset($message)) { echo "<p class='message'>$message</p>"; } ?>
        <form method="POST" action="">
            <div class="checkbox-group">
                <label>Opções da Página White:</label><br>
                <input type="checkbox" id="redirect" name="white_option" value="redirect" <?php if ($white_option === 'redirect') echo 'checked'; ?>> Redirecionar para URL<br>
                <input type="checkbox" id="error404" name="white_option" value="404" <?php if ($white_option === '404') echo 'checked'; ?>> Mostrar como erro 404<br>
                <input type="checkbox" id="slug_raiz" name="white_option" value="slug_raiz" <?php if ($white_option === 'slug_raiz') echo 'checked'; ?>> Adicionar slug na raiz<br>
            </div>

            <label id="white_label" for="white_page">Página White - Adicione aqui a slug da sua página white:</label>
            <input type="text" id="white_page" name="white_page" value="<?php echo $current_white; ?>" placeholder="Página White" required><br>

            <label for="black_page">Página Black - Adicione aqui a slug da sua página black:</label>
            <input type="text" name="black_page" value="<?php echo $current_black; ?>" placeholder="Página Black" required><br>

            <button type="submit">Salvar Configurações</button>
        </form>
    </div>
</body>
</html>
